FrameMut

Trait FrameMut 

pub trait FrameMut: Frame {
    type FrameMut<'this>: FrameMut<Sample = Self::Sample>
       where Self: 'this;
    type IterMut<'this>: Iterator<Item = &'this mut Self::Sample>
       where Self: 'this;

    // Required methods
    fn as_sample_mut(&mut self) -> Self::FrameMut<'_>;
    fn get_mut(&mut self, channel: usize) -> Option<&mut Self::Sample>;
    fn iter_mut(&mut self) -> Self::IterMut<'_>;
}
The buffer of a single frame.

Required Associated Types

type FrameMut<'this>: FrameMut<Sample = Self::Sample> where Self: 'this

The type the frame assumes when coerced into a reference.

type IterMut<'this>: Iterator<Item = &'this mut Self::Sample> where Self: 'this

A borrowing iterator over the channel.

Required Methods

fn as_sample_mut(&mut self) -> Self::FrameMut<'_>

Reborrow the current frame as a reference.

fn get_mut(&mut self, channel: usize) -> Option<&mut Self::Sample>

Get the sample mutable at the given channel in the frame.

fn iter_mut(&mut self) -> Self::IterMut<'_>

Construct a mutable iterator over the frame.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors